@@ -5,7 +5,7 @@ use warnings;
 use Plack::Util::Accessor qw(content renderer);
 use Text::MicroTemplate;
 use Data::Dump;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub new {
     my $proto = shift;
@@ -37,43 +37,34 @@ sub title {
     $name =~ s/(?<=[a-z])(?=[A-Z])/ /g;
     $name;
 }
+sub nav_title {
+    my $self = shift;
+    $self->title;
+}
 sub nav_subtitle { '' }
 
 sub vardump {
     my $scalar = shift;
-    return $scalar unless ref $scalar;
-    Data::Dump::dump($scalar);
+    return "$scalar" unless ref $scalar;
+    scalar Data::Dump::dump($scalar);
 }
 
-sub renderer_vars {
-    my %vars = (
-        cycle => sub {
-            our @cycle;
-            @cycle = @_ unless @cycle;
-            our $pointer;
-            $pointer ||= 0;
-            my $result = $cycle[$pointer];
-            $pointer = ($pointer + 1) % scalar(@cycle);
-            $result;
-        }
-    );
-    wantarray ? %vars : \%vars;
-}
-
-sub render {
-    my ($self, $template, $vars) = @_;
-    my $mt = Text::MicroTemplate->new(
-        template => $template,
+sub build_template {
+    my $class = shift;
+    Text::MicroTemplate->new(
+        template => $_[0],
         tag_start => '<%',
         tag_end => '%>',
         line_start => '%',
     )->build;
-    my $out = $mt->({ $self->renderer_vars, %$vars });
-    $out;
 }
 
-sub template_for_list_pairs {
-    <<'EOTMPL' }
+sub render {
+    my ($self, $template, $vars) = @_;
+    $template->($vars);
+}
+
+my $list_template = __PACKAGE__->build_template(<<'EOTMPL');
 <table>
     <thead>
         <tr>
@@ -96,12 +87,13 @@ EOTMPL
 
 sub render_list_pairs {
     my ($self, $list) = @_;
-    $self->render($self->template_for_list_pairs, { list => $list });
+    $self->render($list_template, { list => $list });
 }
 
 sub render_hash {
     my ($self, $hash) = @_;
-    $self->render($self->template_for_list_pairs, { list => [ %$hash ] });
+    my @hash = map { $_ => $hash->{$_} } sort keys %$hash;
+    $self->render($list_template, { list => \@hash });
 }
 
 1;
