@@ -2,15 +2,15 @@ package Plack::Middleware::Debug::DBITrace;
 use 5.008;
 use strict;
 use warnings;
+use Plack::Util::Accessor qw(level);
 use parent qw(Plack::Middleware::Debug::Base);
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
-sub TEMPLATE {
-    <<'EOTMPL' }
+my $template = __PACKAGE__->build_template(<<'EOTMPL');
 <table>
     <tbody>
 % my $i;
-% for my $line (@{$_[0]->{dump}}) {
+% for my $line (split "\n", $_[0]->{dump}) {
             <tr class="<%= ++$i % 2 ? 'plDebugEven' : 'plDebugOdd' %>">
                 <td><%= $line %></td>
             </tr>
@@ -18,14 +18,26 @@ sub TEMPLATE {
     </tbody>
 </table>
 EOTMPL
-sub nav_title { 'DBI Trace' }
+
+sub init {
+    my $self = shift;
+    $self->SUPER::init(@_);
+    $self->level(1) unless defined $self->level;
+}
+
+sub title     { 'DBI Trace' }
+sub nav_subtitle {
+    my $self = shift;
+    sprintf 'Level %s', $self->level;
+}
 
 sub process_request {
     my ($self, $env) = @_;
     if (defined &DBI::trace) {
         $env->{'plack.debug.dbi.trace'} = DBI->trace;
         open my $fh, ">", \my $output;
-        DBI->trace("1,SQL", $fh);
+        my $level = $self->level;
+        DBI->trace("$level,SQL", $fh);
         $env->{'plack.debug.dbi.output'} = \$output;
     }
 }
@@ -35,11 +47,7 @@ sub process_response {
     if (defined(my $trace = $env->{'plack.debug.dbi.trace'})) {
         DBI->trace($trace);    # reset
         my $dump = $env->{'plack.debug.dbi.output'};
-        $self->content(
-            $self->render(
-                $self->TEMPLATE, { dump => [ split /\n/ => $$dump ] }
-            )
-        );
+        $self->content( $self->render($template, { dump => $$dump }) );
     }
 }
 1;
