@@ -3,11 +3,10 @@ use 5.008;
 use strict;
 use warnings;
 use parent qw(Plack::Middleware::Debug::Base);
-our $VERSION = '0.02';
-sub nav_title { 'Environment' }
+our $VERSION = '0.03';
 
-sub process_request {
-    my ($self, $env) = @_;
+sub process_response {
+    my ($self, $res, $env) = @_;
     $self->content($self->render_hash($env));
 }
 1;
